@@ -59,22 +59,22 @@ case token_bl_##x:\
 #define CASE_GET_NVU32(id) \
 case token_##id:\
 	if (bct == NULL) return -ENODATA; \
-	*((u_int32_t *)data) = bct_ptr->id; \
+	*((uint32_t *)data) = bct_ptr->id; \
 	break
 
 #define CASE_GET_CONST(id, val) \
 case token_##id:\
-	*((u_int32_t *)data) = val; \
+	*((uint32_t *)data) = val; \
 	break
 
 #define CASE_GET_CONST_PREFIX(id, val_prefix) \
 case token_##id:\
-	*((u_int32_t *)data) = val_prefix##_##id; \
+	*((uint32_t *)data) = val_prefix##_##id; \
 	break
 
 #define CASE_SET_NVU32(id) \
 case token_##id:\
-	bct_ptr->id = *((u_int32_t *)data); \
+	bct_ptr->id = *((uint32_t *)data); \
 	break
 
 #define CASE_GET_DATA(id, size) \
@@ -113,9 +113,9 @@ parse_token t114_root_token_list[] = {
 
 int
 t114_set_dev_param(build_image_context *context,
-	u_int32_t index,
+	uint32_t index,
 	parse_token token,
-	u_int32_t value)
+	uint32_t value)
 {
 	nvboot_config_table *bct = NULL;
 
@@ -149,9 +149,9 @@ t114_set_dev_param(build_image_context *context,
 
 int
 t114_get_dev_param(build_image_context *context,
-	u_int32_t index,
+	uint32_t index,
 	parse_token token,
-	u_int32_t *value)
+	uint32_t *value)
 {
 	nvboot_config_table *bct = NULL;
 
@@ -183,9 +183,9 @@ t114_get_dev_param(build_image_context *context,
 
 int
 t114_get_sdram_param(build_image_context *context,
-		u_int32_t index,
+		uint32_t index,
 		parse_token token,
-		u_int32_t *value)
+		uint32_t *value)
 {
 	nvboot_sdram_params *params;
 	nvboot_config_table *bct = NULL;
@@ -514,9 +514,9 @@ t114_get_sdram_param(build_image_context *context,
 
 int
 t114_set_sdram_param(build_image_context *context,
-		u_int32_t index,
+		uint32_t index,
 		parse_token token,
-		u_int32_t value)
+		uint32_t value)
 {
 	nvboot_sdram_params *params;
 	nvboot_config_table *bct = NULL;
@@ -846,10 +846,10 @@ t114_set_sdram_param(build_image_context *context,
 }
 
 int
-t114_getbl_param(u_int32_t set,
+t114_getbl_param(uint32_t set,
 		parse_token id,
-		u_int32_t *data,
-		u_int8_t *bct)
+		uint32_t *data,
+		uint8_t *bct)
 {
 	nvboot_config_table *bct_ptr = (nvboot_config_table *)bct;
 
@@ -881,10 +881,10 @@ t114_getbl_param(u_int32_t set,
 }
 
 int
-t114_setbl_param(u_int32_t set,
+t114_setbl_param(uint32_t set,
 		parse_token id,
-		u_int32_t *data,
-		u_int8_t *bct)
+		uint32_t *data,
+		uint8_t *bct)
 {
 	nvboot_config_table *bct_ptr = (nvboot_config_table *)bct;
 
@@ -916,7 +916,7 @@ t114_setbl_param(u_int32_t set,
 }
 
 int
-t114_bct_get_value(parse_token id, void *data, u_int8_t *bct)
+t114_bct_get_value(parse_token id, void *data, uint8_t *bct)
 {
 	nvboot_config_table *bct_ptr = (nvboot_config_table *)bct;
 	nvboot_config_table  samplebct; /* Used for computing offsets. */
@@ -944,13 +944,13 @@ t114_bct_get_value(parse_token id, void *data, u_int8_t *bct)
 	case token_block_size:
 		if (bct == NULL)
 			return -ENODATA;
-		*((u_int32_t *)data) = 1 << bct_ptr->block_size_log2;
+		*((uint32_t *)data) = 1 << bct_ptr->block_size_log2;
 		break;
 
 	case token_page_size:
 		if (bct == NULL)
 			return -ENODATA;
-		*((u_int32_t *)data) = 1 << bct_ptr->page_size_log2;
+		*((uint32_t *)data) = 1 << bct_ptr->page_size_log2;
 		break;
 
 	/*
@@ -967,26 +967,26 @@ t114_bct_get_value(parse_token id, void *data, u_int8_t *bct)
 		break;
 
 	case token_reserved_offset:
-		*((u_int32_t *)data) = (u_int8_t *)&(samplebct.reserved)
-				- (u_int8_t *)&samplebct;
+		*((uint32_t *)data) = (uint8_t *)&(samplebct.reserved)
+				- (uint8_t *)&samplebct;
 		break;
 
 	case token_bct_size:
-		*((u_int32_t *)data) = sizeof(nvboot_config_table);
+		*((uint32_t *)data) = sizeof(nvboot_config_table);
 		break;
 
 	CASE_GET_CONST(hash_size, sizeof(nvboot_hash));
 
 	case token_crypto_offset:
 		/* Offset to region in BCT to encrypt & sign */
-		*((u_int32_t *)data) = (u_int8_t *)&(samplebct.random_aes_blk)
-				- (u_int8_t *)&samplebct;
+		*((uint32_t *)data) = (uint8_t *)&(samplebct.random_aes_blk)
+				- (uint8_t *)&samplebct;
 		break;
 
 	case token_crypto_length:
 		/* size of region in BCT to encrypt & sign */
-		*((u_int32_t *)data) = (u_int8_t *)bct_ptr + sizeof(nvboot_config_table)
-				- (u_int8_t *)&(bct_ptr->random_aes_blk);
+		*((uint32_t *)data) = (uint8_t *)bct_ptr + sizeof(nvboot_config_table)
+				- (uint8_t *)&(bct_ptr->random_aes_blk);
 		break;
 
 	CASE_GET_CONST(max_bct_search_blks, NVBOOT_MAX_BCT_SEARCH_BLOCKS);
@@ -1012,7 +1012,7 @@ t114_bct_get_value(parse_token id, void *data, u_int8_t *bct)
 }
 
 int
-t114_bct_set_value(parse_token id, void *data, u_int8_t *bct)
+t114_bct_set_value(parse_token id, void *data, uint8_t *bct)
 {
 	nvboot_config_table *bct_ptr = (nvboot_config_table *)bct;
 
@@ -1041,9 +1041,9 @@ t114_bct_set_value(parse_token id, void *data, u_int8_t *bct)
 
 int
 t114_bct_set_data(parse_token id,
-	u_int8_t *data,
-	u_int32_t length,
-	u_int8_t *bct)
+	uint8_t *data,
+	uint32_t length,
+	uint8_t *bct)
 {
 	nvboot_config_table *bct_ptr = (nvboot_config_table *)bct;
 
@@ -1082,7 +1082,7 @@ int t114_bct_token_supported(parse_token token)
 
 void t114_init_bad_block_table(build_image_context *context)
 {
-	u_int32_t bytes_per_entry;
+	uint32_t bytes_per_entry;
 	nvboot_badblock_table *table;
 	nvboot_config_table *bct;
 
